@@ -1,7 +1,7 @@
 library("quanteda")
 
 test_that("textstat_lexdiv computation is correct", {
-    mydfm <- quanteda::dfm(tokens(c(d1 = "b a b a b a b a",
+    mydfm <- dfm(tokens(c(d1 = "b a b a b a b a",
                              d2 = "a a b b")))
     expect_equivalent(
         textstat_lexdiv(mydfm, "TTR"),
@@ -11,7 +11,7 @@ test_that("textstat_lexdiv computation is correct", {
 })
 
 test_that("textstat_lexdiv CTTR works correctly", {
-    mydfm <- quanteda::dfm(tokens(c(d1 = "b a b a b a b a",
+    mydfm <- dfm(tokens(c(d1 = "b a b a b a b a",
                              d2 = "a a b b")))
     expect_equivalent(
         textstat_lexdiv(mydfm, "CTTR")$CTTR,
@@ -21,7 +21,7 @@ test_that("textstat_lexdiv CTTR works correctly", {
 })
 
 test_that("textstat_lexdiv R works correctly", {
-    mydfm <-quanteda:: dfm(tokens(c(d1 = "b a b a b a b a",
+    mydfm <- dfm(tokens(c(d1 = "b a b a b a b a",
                              d2 = "a a b b")))
     expect_equivalent(
         textstat_lexdiv(mydfm, "R")$R,
@@ -31,7 +31,7 @@ test_that("textstat_lexdiv R works correctly", {
 })
 
 test_that("textstat_lexdiv C works correctly", {
-    mydfm <- quanteda::dfm(tokens(c(d1 = "b a b a b a b a",
+    mydfm <- dfm(tokens(c(d1 = "b a b a b a b a",
                              d2 = "a a b b")))
     expect_equivalent(
         textstat_lexdiv(mydfm, "C")$C,
@@ -41,7 +41,7 @@ test_that("textstat_lexdiv C works correctly", {
 })
 
 test_that("textstat_lexdiv Maas works correctly", {
-    mydfm <- quanteda::dfm(tokens(c(d1 = "b a b a b a b a",
+    mydfm <- dfm(tokens(c(d1 = "b a b a b a b a",
                    d2 = "a a b b")))
     expect_equivalent(
         textstat_lexdiv(mydfm, "Maas")$Maas[1],
@@ -51,7 +51,7 @@ test_that("textstat_lexdiv Maas works correctly", {
 })
 
 test_that("textstat_lexdiv Yule's I works correctly", {
-    mydfm <- quanteda::dfm(tokens(c(d1 = "a b c",
+    mydfm <- dfm(tokens(c(d1 = "a b c",
                    d2 = "a a b b c")))
     expect_equivalent(
         textstat_lexdiv(mydfm, "I")$I[1], 0, tolerance = 0.01
@@ -63,7 +63,7 @@ test_that("textstat_lexdiv Yule's I works correctly", {
 
 test_that("textstat_lexdiv works with a single document dfm (#706)", {
     mytxt <- "one one two one one two one"
-    mydfm <- quanteda::dfm(tokens(mytxt))
+    mydfm <- dfm(tokens(mytxt))
     expect_equivalent(
         textstat_lexdiv(mydfm, c("TTR", "C")),
         data.frame(document = "text1", TTR = 0.286, C = 0.356,
@@ -73,7 +73,7 @@ test_that("textstat_lexdiv works with a single document dfm (#706)", {
 })
 
 test_that("raises error when dfm is empty (#1419)", {
-    mx <- quanteda::dfm_trim(quanteda::data_dfm_lbgexample, 1000)
+    mx <- dfm_trim(data_dfm_lbgexample, 1000)
     expect_error(textstat_lexdiv(mx, c("TTR", "C")),
                  quanteda.textstats:::message_error("dfm_empty"))
 })
@@ -84,28 +84,30 @@ test_that("Yule's K and Herndon's Vm correction are (approximately) correct", {
     # “Yule's Characteristic K Revisited.” Language Resources and Evaluation
     # 39(4): 287–94.
     # text source: http://www.latinvulgate.com/verse.aspx?t=1&b=4&c=1
-    data_corpus_stjohn <- read.csv("../data/stjohn_latin.csv", stringsAsFactors = FALSE) %>%
-        quanteda::corpus(text_field = "latin") %>%
-        quanteda::texts(groups = "chapter") %>%  # combine verses into a single document
-        quanteda::corpus(docvars = data.frame(chapter = 1:4))
-    quanteda::docnames(data_corpus_stjohn) <- paste0("chap", 1:4)
+    df <- read.csv("../data/stjohn_latin.csv", stringsAsFactors = FALSE)
+    data_corpus_stjohn <- df %>%
+        corpus(text_field = "latin") %>%
+        corpus_group(groups = df$chapter) # %>%
+        # as.character() %>%  # combine verses into a single document
+        # corpus(docvars = data.frame(chapter = 1:4))
+    docnames(data_corpus_stjohn) <- paste0("chap", 1:4)
 
     data_dfm_stjohn <- data_corpus_stjohn %>%
-        quanteda::tokens(remove_punct = TRUE) %>%
-        quanteda::tokens_tolower() %>%
-        quanteda::dfm()
+        tokens(remove_punct = TRUE) %>%
+        tokens_tolower() %>%
+        dfm()
 
     # work with chapter 1
-    data_dfm_stjohnch1 <- quanteda::dfm_subset(data_dfm_stjohn, chapter == 1)
+    data_dfm_stjohnch1 <- dfm_subset(data_dfm_stjohn, chapter == 1)
 
     expect_equal(
-        as.integer(quanteda::ntoken(data_dfm_stjohnch1)), # 770
+        as.integer(ntoken(data_dfm_stjohnch1)), # 770
         755L,     # from Miranda-Garcia and Calle-Martin (2005, Table 1)
         tol = 15  # might differ b/c of different translations, spellings, or token-counting method
     )
 
     expect_equal(
-        as.integer(quanteda::ntype(data_dfm_stjohnch1)),  # 329
+        as.integer(ntype(data_dfm_stjohnch1)),  # 329
         331L,     # from Miranda-Garcia and Calle-Martin (2005, Table 1)
         tol = 2   # might be off because of different translations or token-counting method
     )
@@ -120,8 +122,8 @@ test_that("Yule's K and Herndon's Vm correction are (approximately) correct", {
     # tests on multiple documents - this is Ch 1 and Chs 1-4 as per the first two rows of
     # Table 3 of Miranda-Garcia and Calle-Martin (2005)
     data_dfm_stjohncomb <- rbind(data_dfm_stjohnch1,
-                                 quanteda::dfm_group(data_dfm_stjohn, rep(1, 4)))
-    quanteda::docnames(data_dfm_stjohncomb)[2] <- "chaps1-4"
+                                 dfm_group(data_dfm_stjohn, rep(1, 4)))
+    docnames(data_dfm_stjohncomb)[2] <- "chaps1-4"
     expect_equivalent(
         textstat_lexdiv(data_dfm_stjohncomb, "K"),
         data.frame(document = c("chap1", "chaps1-4"), K = c(126.3366167, 99.43763148),
@@ -144,8 +146,8 @@ test_that("Yule's K and Herndon's Vm correction are (approximately) correct", {
     Vm <- result[["Vm"]]
     expect_equal(
         Vm ^ 2,
-        as.numeric(K / 10 ^ 4 + (1 / quanteda::ntoken(data_dfm_stjohncomb) - 1 /
-                                     quanteda::ntype(data_dfm_stjohncomb))),
+        as.numeric(K / 10 ^ 4 + (1 / ntoken(data_dfm_stjohncomb) - 1 /
+                                     ntype(data_dfm_stjohncomb))),
         tol = .0013
     )
 })
@@ -156,8 +158,8 @@ static_measures <- c("TTR", "C", "R", "CTTR", "U", "S", "K", "D", "Vm", "Maas")
 test_that("textstat_lexdiv works similarly for corpus and tokens", {
     txt <- c(d1 = "b a b a b a b a",
              d2 = "a a b b")
-    mydfm <- quanteda::dfm(tokens(txt))
-    mytokens <- quanteda::tokens(txt)
+    mydfm <- dfm(tokens(txt))
+    mytokens <- tokens(txt)
     expect_identical(
         textstat_lexdiv(mydfm, measure = static_measures),
         textstat_lexdiv(mytokens, measure = static_measures)
@@ -167,8 +169,8 @@ test_that("textstat_lexdiv works similarly for corpus and tokens", {
 test_that("textstat_lexdiv supports removal of punctuation, numbers and symbols", {
     txt <- c(d1 = "a a  b b  c c",
              d2 = "a a , b b . c c / & ^ *** ### 1 2 3 4")
-    mt <- quanteda::dfm(tokens(txt))
-    toks <- quanteda::tokens(txt)
+    mt <- dfm(tokens(txt))
+    toks <- tokens(txt)
     expect_identical(
         textstat_lexdiv(mt["d1", ], measure = static_measures)[, -1],
         textstat_lexdiv(mt["d2", ], measure = static_measures)[, -1]
@@ -180,9 +182,9 @@ test_that("textstat_lexdiv supports removal of punctuation, numbers and symbols"
 })
 
 test_that("textstat_lexdiv supports removal of hyphenation", {
-    y <- quanteda::dfm(tokens(c(d1 = "apple-pear orange-fruit elephant-ferrari",
+    y <- dfm(tokens(c(d1 = "apple-pear orange-fruit elephant-ferrari",
                d2 = "alpha-beta charlie-delta echo-foxtrot")))
-    z <- quanteda::dfm(tokens(c(d1 = "apple pear orange fruit elephant ferrari",
+    z <- dfm(tokens(c(d1 = "apple pear orange fruit elephant ferrari",
                d2 = "alpha beta charlie delta echo foxtrot")))
     expect_identical(
         textstat_lexdiv(y, measure = static_measures, remove_hyphens = TRUE),
@@ -191,11 +193,11 @@ test_that("textstat_lexdiv supports removal of hyphenation", {
 })
 
 test_that("textstat_lexdiv can handle hyphenated words containing duplicated tokens ", {
-    dfm_nested <- quanteda::dfm(tokens(quanteda::corpus(c(d1 = "have we not-we-have bicycle ! % 123 ^ "))))
+    dfm_nested <- dfm(tokens(corpus(c(d1 = "have we not-we-have bicycle ! % 123 ^ "))))
     # not-we-have should be separated into three tokens, with hyphens being removed
     # remaining punctuation, symbols and numbers should also be removed
     # dfm_nested should only have 4 types with 6 tokens
-    dfm_non_nested <- quanteda::dfm(tokens(quanteda::corpus(c(d1 = "a b b c c d"))))
+    dfm_non_nested <- dfm(tokens(corpus(c(d1 = "a b b c c d"))))
     expect_identical(textstat_lexdiv(dfm_nested, measure = static_measures, remove_hyphens = TRUE),
                      textstat_lexdiv(dfm_non_nested, measure = static_measures))
 })
@@ -208,37 +210,37 @@ test_that("textstat_lexdiv.dfm and .tokens work same with remove_* options", {
               sandwich.",
              "A shrimp-kabob costs $0.50, shrimp costs $0.25.")
     expect_identical(
-        textstat_lexdiv(quanteda::tokens(txt), measure = "TTR", remove_hyphens = TRUE),
-        textstat_lexdiv(quanteda::dfm(tokens(txt), tolower = FALSE), measure = "TTR", remove_hyphens = TRUE)
+        textstat_lexdiv(tokens(txt), measure = "TTR", remove_hyphens = TRUE),
+        textstat_lexdiv(dfm(tokens(txt), tolower = FALSE), measure = "TTR", remove_hyphens = TRUE)
     )
     expect_identical(
-        textstat_lexdiv(quanteda::tokens(txt), measure = "TTR",
+        textstat_lexdiv(tokens(txt), measure = "TTR",
                         remove_punct = TRUE, remove_hyphens = TRUE),
-        textstat_lexdiv(quanteda::dfm(tokens(txt)), measure = "TTR",
+        textstat_lexdiv(dfm(tokens(txt)), measure = "TTR",
                         remove_punct = TRUE, remove_hyphens = TRUE)
     )
     expect_identical(
-        textstat_lexdiv(quanteda::tokens(txt), measure = "TTR", remove_punct = TRUE),
-        textstat_lexdiv(quanteda::dfm(tokens(txt)), measure = "TTR", remove_punct = TRUE)
+        textstat_lexdiv(tokens(txt), measure = "TTR", remove_punct = TRUE),
+        textstat_lexdiv(dfm(tokens(txt)), measure = "TTR", remove_punct = TRUE)
     )
     expect_identical(
-        textstat_lexdiv(quanteda::tokens(txt[2]), measure = "TTR", remove_symbols = TRUE),
-        textstat_lexdiv(quanteda::dfm(tokens(txt[2])), measure = "TTR", remove_symbols = TRUE)
+        textstat_lexdiv(tokens(txt[2]), measure = "TTR", remove_symbols = TRUE),
+        textstat_lexdiv(dfm(tokens(txt[2])), measure = "TTR", remove_symbols = TRUE)
     )
     expect_true(
-        textstat_lexdiv(quanteda::dfm(tokens(txt[2])), measure = "TTR", remove_symbols = TRUE)[1, "TTR"] !=
-        textstat_lexdiv(quanteda::dfm(tokens(txt[2])), measure = "TTR", remove_symbols = FALSE)[1, "TTR"]
+        textstat_lexdiv(dfm(tokens(txt[2])), measure = "TTR", remove_symbols = TRUE)[1, "TTR"] !=
+        textstat_lexdiv(dfm(tokens(txt[2])), measure = "TTR", remove_symbols = FALSE)[1, "TTR"]
     )
     expect_identical(
-        textstat_lexdiv(quanteda::tokens(txt), measure = "TTR", remove_numbers = TRUE),
-        textstat_lexdiv(quanteda::dfm(tokens(txt)), measure = "TTR", remove_numbers = TRUE)
+        textstat_lexdiv(tokens(txt), measure = "TTR", remove_numbers = TRUE),
+        textstat_lexdiv(dfm(tokens(txt)), measure = "TTR", remove_numbers = TRUE)
     )
 })
 
 
 test_that("textstat_lexdiv does not support dfm for MATTR and MSTTR", {
     mytxt <- "one one two one one two one"
-    mydfm <- quanteda::dfm(tokens(mytxt))
+    mydfm <- dfm(tokens(mytxt))
     expect_error(
         textstat_lexdiv(mydfm, measure = "MATTR"),
         "average-based measures are only available for tokens inputs"
@@ -252,7 +254,7 @@ test_that("textstat_lexdiv does not support dfm for MATTR and MSTTR", {
 test_that("textstat_lexdiv.tokens raises errors if parameters for moving measures are not specified", {
     # skip("defaults may have changed")
     mytxt <- "one one two one one two one"
-    mytoken <- quanteda::tokens(mytxt)
+    mytoken <- tokens(mytxt)
 
     expect_warning(
         textstat_lexdiv(mytoken, measure = "MATTR", MATTR_window = 100),
@@ -266,7 +268,7 @@ test_that("textstat_lexdiv.tokens raises errors if parameters for moving measure
 
 test_that("textstat_lexdiv.tokens MATTR works correctly on its own", {
     mytxt <- "one one two one one two one"
-    mytoken <- quanteda::tokens(mytxt)
+    mytoken <- tokens(mytxt)
     wsize2_MATTR <- (1/2 + 1 + 1 + 1/2 + 1 + 1) / 6
     wsize3_MATTR <- (2/3 + 2/3 + 2/3 + 2/3 + 2/3) / 5
     wsize4_MATTR <- (2/4 + 2/4 + 2/4 + 2/4) / 4
@@ -292,7 +294,7 @@ test_that("textstat_lexdiv.tokens MATTR works correctly on its own", {
 
 test_that("textstat_lexdiv.tokens MATTR works correctly in conjunction with static measures", {
     mytxt <- "one one two one one two one"
-    mytoken <- quanteda::tokens(mytxt)
+    mytoken <- tokens(mytxt)
     wsize2_MATTR <- (1/2 + 1 + 1 + 1/2 + 1 + 1) / 6
 
     expect_equivalent(
@@ -303,7 +305,7 @@ test_that("textstat_lexdiv.tokens MATTR works correctly in conjunction with stat
 
 test_that("textstat_lexdiv.tokens MSTTR works correctly on its own", {
     mytxt <- "apple orange apple orange pear pear apple orange"
-    mytoken <- quanteda::tokens(mytxt)
+    mytoken <- tokens(mytxt)
     wsize2_MSTTR <- (2/2 + 2/2 + 1/2 + 2/2) / 4
     wsize3_MSTTR <- (2/3 + 2/3 ) / 2 # apple orange at the back is discarded
     wsize4_MSTTR <- (2/4 + 3/4) / 2
@@ -331,7 +333,7 @@ test_that("textstat_lexdiv.tokens MSTTR works correctly on its own", {
 
 test_that("textstat_lexdiv.tokens MSTTR works correctly in conjunction with static measures", {
     mytxt <- "apple orange apple orange pear pear apple orange"
-    mytoken <- quanteda::tokens(mytxt)
+    mytoken <- tokens(mytxt)
     wsize2_MSTTR <- (2/2 + 2/2 + 1/2 + 2/2) / 4
 
     expect_equivalent(
@@ -343,7 +345,7 @@ test_that("textstat_lexdiv.tokens MSTTR works correctly in conjunction with stat
 
 test_that("compute_MSTTR internal function has working exception handlers", {
     mytxt <- "apple orange apple orange pear pear apple orange"
-    mytoken <- quanteda::tokens(mytxt)
+    mytoken <- tokens(mytxt)
 
     expect_warning(
         quanteda.textstats:::compute_msttr(mytoken, 20),
@@ -372,7 +374,7 @@ test_that("compute_MSTTR internal function has working exception handlers", {
 test_that("textstat_lexdiv.tokens works right when all measures are requested", {
     skip("until all MA measures are made functional")
     mytxt <- "apple orange apple orange pear pear apple orange"
-    mytoken <- quanteda::tokens(mytxt)
+    mytoken <- tokens(mytxt)
     wsize2_MATTR <- (2/2 + 2/2 + 2/2 + 2/2 + 1/2 + 2/2 + 2/2) / 7
     wsize2_MSTTR <- (2/2 + 2/2 + 1/2 + 1) /4 # 7th entry is discarded
 
@@ -389,7 +391,7 @@ test_that("textstat_lexdiv.tokens works right when all measures are requested",
 })
 
 test_that("textstat_lexdiv works with measure = 'all'", {
-    res <- textstat_lexdiv(quanteda::dfm(quanteda::tokens("What, oh what, are we doing?")),
+    res <- textstat_lexdiv(dfm(tokens("What, oh what, are we doing?")),
                            measure = "all")
     expect_true(
         setequal(names(res),
@@ -398,9 +400,9 @@ test_that("textstat_lexdiv works with measure = 'all'", {
 })
 
 test_that("dfm_split_hyphenated_features works as expected", {
-    dfmat <- quanteda::dfm(quanteda::tokens("One-two one two three."))
+    dfmat <- dfm(tokens("One-two one two three."))
     expect_identical(
-        quanteda::featnames(quanteda.textstats:::dfm_split_hyphenated_features(dfmat)),
+        featnames(quanteda.textstats:::dfm_split_hyphenated_features(dfmat)),
         c("one", "two", "three", ".", "-")
     )
 })
